NAME

SLM::Lib

SYNOPSIS

Not really appropriate.  See individual functions.

DESCRIPTION

A collection of GenPerl utility functions.

LICENSE

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

FEEDBACK

Currently, all feedback should be sent directly to the author.

AUTHOR - Steve Mathias

Email: mathias@genomica.com

Phone: (720) 565-4029

Address: Genomica Corporation 1745 38th Street Boulder, CO 80301

DETAILS

The rest of the documentation describes each of the object variables and methods. The names of internal variables and methods are preceded with an underscore (_).

now

Function  : Generate a text representation of the current date/time
Arguments : Hash
Returns   : Scalar text string
Example   : print LOG now(format => 'fancy')
Scope     : Public
Comments  : Formats: raw       : comma-delimited output from localtime(time)
                     simple    : "1965-11-14 12:45:44"
                     dayonly   : "14 November 1965"
                     fancy     : "Friday November 14, 1965 12:45:44"
                     mysqldate : "1965-11-14"

browse

Function  : A simple de-referencing browser for perl data structures
Arguments : Scalar
Returns   : N/A
Example   : browse()
Scope     : Public
Comments  : See also structure2Str()

structure2Str

Function  : Convert a pointer to a complex perl data structure into a string 
            for printing.
Arguments : Scalar
Returns   : N/A
Example   : browse()
Scope     : Private Class Method
Comments  : Recurses if nested pointers exist in the data structure.